==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/analysisservices/kotlin/inputs/ServerAdministratorsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.analysisservices.kotlin.inputs

import com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * An array of administrator user identities.
 * @property members An array of administrator user identities.
 */
public data class ServerAdministratorsArgs(
    public val members: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs> {
    override fun toJava(): com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs =
        com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs.builder()
            .members(members?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ServerAdministratorsArgs].
 */
@PulumiTagMarker
public class ServerAdministratorsArgsBuilder internal constructor() {
    private var members: Output<List<String>>? = null

    /**
     * @param value An array of administrator user identities.
     */
    @JvmName("ybaiaonafxhqtjto")
    public suspend fun members(`value`: Output<List<String>>) {
        this.members = value
    }

    @JvmName("tbqugcgmetiyjglw")
    public suspend fun members(vararg values: Output<String>) {
        this.members = Output.all(values.asList())
    }

    /**
     * @param values An array of administrator user identities.
     */
    @JvmName("tlaxhoohrlawuvos")
    public suspend fun members(values: List<Output<String>>) {
        this.members = Output.all(values)
    }

    /**
     * @param value An array of administrator user identities.
     */
    @JvmName("drjclnpipjxaunuv")
    public suspend fun members(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.members = mapped
    }

    /**
     * @param values An array of administrator user identities.
     */
    @JvmName("kqckooyvrpfpmpsi")
    public suspend fun members(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.members = mapped
    }

    internal fun build(): ServerAdministratorsArgs = ServerAdministratorsArgs(
        members = members,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/analysisservices/kotlin/inputs/ServerAdministratorsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.analysisservices.kotlin.inputs

import com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * An array of administrator user identities.
 * @property members An array of administrator user identities.
 */
public data class ServerAdministratorsArgs(
    public val members: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs> {
    override fun toJava(): com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs =
        com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs.builder()
            .members(members?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ServerAdministratorsArgs].
 */
@PulumiTagMarker
public class ServerAdministratorsArgsBuilder internal constructor() {
    private var members: Output<List<String>>? = null

    /**
     * @param value An array of administrator user identities.
     */
    @JvmName("amkuesrbplsjqfdx")
    public suspend fun members(`value`: Output<List<String>>) {
        this.members = value
    }

    @JvmName("cuagejrburhhbobb")
    public suspend fun members(vararg values: Output<String>) {
        this.members = Output.all(values.asList())
    }

    /**
     * @param values An array of administrator user identities.
     */
    @JvmName("mpkuhjvdprjjjssj")
    public suspend fun members(values: List<Output<String>>) {
        this.members = Output.all(values)
    }

    /**
     * @param value An array of administrator user identities.
     */
    @JvmName("qeesybqtfqndwitu")
    public suspend fun members(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.members = mapped
    }

    /**
     * @param values An array of administrator user identities.
     */
    @JvmName("mshruibriqpeeebo")
    public suspend fun members(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.members = mapped
    }

    internal fun build(): ServerAdministratorsArgs = ServerAdministratorsArgs(
        members = members,
    )
}
